@@ -12,7 +12,7 @@ class Payment(JunoEntity):
 		cls.chargeId = String(max=100)
 		cls.date = DateTime(format="iso")
 		cls.releaseDate = DateTime(format="iso")
-		cls.amount = Float(),
+		cls.amount = Float()
 		cls.fee = Float()
 		cls.type = String(max=30)
 		cls.status = String(max=30)
